@@ -5,8 +5,8 @@ testthat::test_that(
   "upload obeys timestamp only when newer", {
     testthat::skip_on_travis() ## No idea.
 
-    testthat::skip_if(piggyback:::get_token() == "")
-    testthat::skip_if(piggyback:::get_token() ==
+    testthat::skip_if(gh::gh_token() == "")
+    testthat::skip_if(gh::gh_token() ==
                         "b2b7441daeeb010b1df26f1f60a7f1edc485e443")
     testthat::skip_if(Sys.getenv("CBOETTIG_TOKEN") == "")
 
